@@ -1,6 +1,6 @@
 #' Cohen's *d* and Other Standardized Differences
 #'
-#' Compute effect size indices for standardized differences: Cohen's *d*,
+#' Compute effect size indices for standardized mean differences: Cohen's *d*,
 #' Hedges' *g* and Glass’s *delta* (\eqn{\Delta}). (This function returns the
 #' **population** estimate.) Pair with any reported [`stats::t.test()`].
 #' \cr\cr
@@ -9,7 +9,7 @@
 #' correction for small-sample bias (using the exact method) to Cohen's *d*. For
 #' sample sizes > 20, the results for both statistics are roughly equivalent.
 #' Glass’s *delta* is appropriate when the standard deviations are significantly
-#' different between the populations, as it uses only the *second* group's
+#' different between the populations, as it uses only the reference group's
 #' standard deviation.
 #'
 #' @param x,y A numeric vector, or a character name of one in `data`.
@@ -29,6 +29,8 @@
 #' @param adjust Should the effect size be adjusted for small-sample bias using
 #'   Hedges' method? Note that `hedges_g()` is an alias for
 #'   `cohens_d(adjust = TRUE)`.
+#' @param reference (Optional) character value of the "group" used as the
+#'   reference. By default, the _second_ group is the reference group.
 #' @param ... Arguments passed to or from other methods. When `x` is a formula,
 #'   these can be `subset` and `na.action`.
 #' @inheritParams chisq_to_phi
@@ -136,6 +138,7 @@
 #' @export
 cohens_d <- function(x, y = NULL, data = NULL,
                      pooled_sd = TRUE, mu = 0, paired = FALSE,
+                     reference = NULL,
                      adjust = FALSE,
                      ci = 0.95, alternative = "two.sided",
                      verbose = TRUE, ...) {
@@ -147,6 +150,7 @@ cohens_d <- function(x, y = NULL, data = NULL,
     y = y, data = data,
     type = "d", adjust = adjust,
     pooled_sd = pooled_sd, mu = mu, paired = paired,
+    reference = reference,
     ci = ci, alternative = alternative,
     verbose = verbose,
     ...
@@ -157,10 +161,11 @@ cohens_d <- function(x, y = NULL, data = NULL,
 #' @export
 hedges_g <- function(x, y = NULL, data = NULL,
                      pooled_sd = TRUE, mu = 0, paired = FALSE,
+                     reference = NULL,
                      ci = 0.95, alternative = "two.sided",
                      verbose = TRUE, ...) {
   cl <- match.call()
-  cl[[1]] <- quote(cohens_d)
+  cl[[1]] <- quote(effectsize::cohens_d)
   cl$adjust <- TRUE
   eval.parent(cl)
 }
@@ -169,6 +174,7 @@ hedges_g <- function(x, y = NULL, data = NULL,
 #' @export
 glass_delta <- function(x, y = NULL, data = NULL,
                         mu = 0, adjust = TRUE,
+                        reference = NULL,
                         ci = 0.95, alternative = "two.sided",
                         verbose = TRUE, ...) {
   .effect_size_difference(
@@ -176,6 +182,7 @@ glass_delta <- function(x, y = NULL, data = NULL,
     y = y, data = data,
     type = "delta",
     mu = mu, adjust = adjust,
+    reference = reference,
     ci = ci, alternative = alternative,
     verbose = verbose,
     pooled_sd = NULL, paired = FALSE,
@@ -189,13 +196,15 @@ glass_delta <- function(x, y = NULL, data = NULL,
 .effect_size_difference <- function(x, y = NULL, data = NULL,
                                     type = "d", adjust = FALSE,
                                     mu = 0, pooled_sd = TRUE, paired = FALSE,
+                                    reference = NULL,
                                     ci = 0.95, alternative = "two.sided",
                                     verbose = TRUE, ...) {
   if (type == "d" && adjust) type <- "g"
 
+  # TODO: Check if we can do anything with `reference` for these classes
   if (type != "delta") {
     if (.is_htest_of_type(x, "t-test")) {
-      return(effectsize(x, type = type, verbose = verbose, ...))
+      return(effectsize(x, type = type, verbose = verbose, data = data, ...))
     } else if (.is_BF_of_type(x, c("BFoneSample", "BFindepSample"), "t-squared")) {
       return(effectsize(x, ci = ci, verbose = verbose, ...))
     }
@@ -203,7 +212,7 @@ glass_delta <- function(x, y = NULL, data = NULL,
 
 
   alternative <- .match.alt(alternative)
-  out <- .get_data_2_samples(x, y, data, paired = paired, verbose = verbose, ...)
+  out <- .get_data_2_samples(x, y, data, paired = paired, reference = reference, verbose = verbose, ...)
   x <- out[["x"]]
   y <- out[["y"]]
   paired <- out[["paired"]]
@@ -219,11 +228,13 @@ glass_delta <- function(x, y = NULL, data = NULL,
       insight::format_error("For Glass' Delta, please provide data from two samples.")
     }
     y <- 0
-    paired <- TRUE
+    is_paired_or_onesample <- TRUE
+  } else {
+    is_paired_or_onesample <- paired
   }
 
   # Compute index
-  if (paired) {
+  if (is_paired_or_onesample) {
     if (type == "delta") {
       insight::format_error("This effect size is only applicable for two independent samples.")
     }
@@ -234,7 +245,7 @@ glass_delta <- function(x, y = NULL, data = NULL,
 
     hn <- 1 / n
     se <- s / sqrt(n)
-    df <- n - 1
+    df1 <- n - 1
 
     pooled_sd <- NULL
   } else {
@@ -252,14 +263,14 @@ glass_delta <- function(x, y = NULL, data = NULL,
         s <- suppressWarnings(sd_pooled(x, y))
         hn <- (1 / n1 + 1 / n2)
         se <- s * sqrt(1 / n1 + 1 / n2)
-        df <- n - 2
+        df1 <- n - 2
       } else {
         s <- sqrt((s1^2 + s2^2) / 2)
         hn <- (2 * (n2 * s1^2 + n1 * s2^2)) / (n1 * n2 * (s1^2 + s2^2))
         se1 <- sqrt(s1^2 / n1)
         se2 <- sqrt(s2^2 / n2)
         se <- sqrt(se1^2 + se2^2)
-        df <- se^4 / (se1^4 / (n1 - 1) + se2^4 / (n2 - 1))
+        df1 <- se^4 / (se1^4 / (n1 - 1) + se2^4 / (n2 - 1))
       }
     } else if (type == "delta") {
       pooled_sd <- NULL
@@ -267,7 +278,7 @@ glass_delta <- function(x, y = NULL, data = NULL,
       s <- s2
       hn <- 1 / n2 + s1^2 / (n1 * s2^2)
       se <- (s2 * sqrt(1 / n2 + s1^2 / (n1 * s2^2)))
-      df <- n2 - 1
+      df1 <- n2 - 1
     }
   }
 
@@ -278,22 +289,21 @@ glass_delta <- function(x, y = NULL, data = NULL,
   if (.test_ci(ci)) {
     # Add cis
     out$CI <- ci
-    ci.level <- .adjust_ci(ci, alternative)
+    ci_level <- .adjust_ci(ci, alternative)
 
-    t <- (d - mu) / se
-    ts <- .get_ncp_t(t, df, ci.level)
+    t1 <- (d - mu) / se
+    ts1 <- .get_ncp_t(t1, df1, ci_level)
 
-    out$CI_low <- ts[1] * sqrt(hn)
-    out$CI_high <- ts[2] * sqrt(hn)
+    out$CI_low <- ts1[1] * sqrt(hn)
+    out$CI_high <- ts1[2] * sqrt(hn)
     ci_method <- list(method = "ncp", distribution = "t")
     out <- .limit_ci(out, alternative, -Inf, Inf)
   } else {
     ci_method <- alternative <- NULL
   }
 
-
   if (adjust) {
-    J <- .J(df)
+    J <- .J(df1)
     col_to_adjust <- intersect(colnames(out), c(types[type], "CI_low", "CI_high"))
     out[, col_to_adjust] <- out[, col_to_adjust] * J
 
@@ -307,10 +317,10 @@ glass_delta <- function(x, y = NULL, data = NULL,
     paired, pooled_sd, mu, ci, ci_method, alternative, adjust,
     approximate = FALSE
   )
-  return(out)
+  out
 }
 
 #' @keywords internal
-.J <- function(df) {
-  exp(lgamma(df / 2) - log(sqrt(df / 2)) - lgamma((df - 1) / 2)) # exact method
+.J <- function(df1) {
+  exp(lgamma(df1 / 2) - log(sqrt(df1 / 2)) - lgamma((df1 - 1) / 2)) # exact method
 }
